@@ -10,8 +10,9 @@ This module uses ReportLab to produce all the needed printouts.
 """
 
 from copy import copy
-from datetime import datetime, timedelta
+from datetime import date, datetime, timedelta
 import locale, logging
+from babel.numbers import format_decimal
 
 logger = logging.getLogger(__name__)
 
@@ -138,7 +139,7 @@ rank_width = 0.8*cm
 scores_width = 1.3*cm
 "The width of the `scores` columns"
 
-prizes_width = 1.4*cm
+prizes_width = 2*cm
 "The width of the `prizes` columns"
 
 
@@ -556,6 +557,7 @@ class Ranking(TourneyPrintout):
         t = translator(request)
         kw = request.params
         args = super().getArgumentsFromRequest(session, request)
+        args.append(getattr(request, '_LOCALE_', 'en'))
         if 'turn' in kw:
             try:
                 args.append(int(kw['turn']))
@@ -565,12 +567,15 @@ class Ranking(TourneyPrintout):
                         mapping=dict(turn=repr(kw['turn'])))))
         return args
 
-    def __init__(self, output, tourney, turn=None):
+    def __init__(self, output, tourney, locale, turn=None):
         super(Ranking, self).__init__(output, tourney, 1)
+        self.locale = locale
         self.turn = turn
 
     def getLitURL(self, request):
-        if not request.host.startswith('localhost'):
+        if (date.today() - self.tourney.date) > timedelta(days=3):
+            return None
+        elif not request.host.startswith('localhost'):
             return request.route_url('lit_tourney', guid=self.tourney.guid)
 
     def getSubTitle(self):
@@ -622,13 +627,20 @@ class Ranking(TourneyPrintout):
                 caption += "<font size=6> %s</font>" % player.club
             return caption
 
+        if self.tourney.championship.prizes in ('asis', 'fixed', 'fixed40', 'millesimal'):
+            def format_prize(p):
+                return '%d' % p
+        else:
+            def format_prize(p):
+                return format_decimal(p, '###0.00', self.locale)
+
         if self.turn is not None:
             ranking = [(i, c.caption(player_caption=player_caption), c.nationality,
                         r.points, r.bucholz, r.netscore, 0)
                        for i, (c, r) in enumerate(self.tourney.computeRanking(self.turn), 1)]
         else:
             ranking = [(i, c.caption(player_caption=player_caption), c.nationality,
-                        c.points, c.bucholz, c.netscore, c.prize)
+                        c.points, c.bucholz, c.netscore, format_prize(c.prize))
                        for i, c in enumerate(self.tourney.ranking, 1)]
 
             if self.tourney.finals and self.tourney.prized:
@@ -671,8 +683,8 @@ class Ranking(TourneyPrintout):
                                   netscore)
                             for (rank, description, country,
                                  points, bucholz, netscore, prize) in ranking)
-                desc_width = (self.doc.width/self.columns*0.9 - rank_width -
-                              scores_width*4 - (scores_width if is_intl else 0))
+                desc_width = (self.doc.width - rank_width - scores_width*4 -
+                              (scores_width if is_intl else 0))
                 widths = (
                     rank_width, scores_width, desc_width,
                     scores_width, scores_width,
@@ -711,8 +723,7 @@ class Ranking(TourneyPrintout):
                                   prize)
                             for (rank, description, country,
                                  points, bucholz, netscore, prize) in ranking)
-                desc_width = (self.doc.width/self.columns*0.9 - rank_width -
-                              scores_width*4 - prizes_width -
+                desc_width = (self.doc.width - rank_width - scores_width*4 - prizes_width -
                               (scores_width if is_intl else 0))
                 widths = (
                     rank_width, scores_width, desc_width,
@@ -990,7 +1001,9 @@ class Results(TourneyPrintout):
         self.turn = turn
 
     def getLitURL(self, request):
-        if not request.host.startswith('localhost') and self.turn:
+        if (date.today() - self.tourney.date) > timedelta(days=3):
+            return None
+        elif not request.host.startswith('localhost') and self.turn:
             return request.route_url('lit_tourney', guid=self.tourney.guid,
                                      _query=dict(turn=self.turn))
 
@@ -1805,12 +1818,13 @@ class RatingRanking(BasicPrintout):
             if entity is None:
                 raise OperationAborted(t(_('Bad rating id')))
 
-        return [entity]
+        return [entity, getattr(request, '_LOCALE_', 'en')]
 
-    def __init__(self, output, rating):
+    def __init__(self, output, rating, locale):
         super().__init__(output, 1)
         self.rating = rating
         self.ranking = rating.ranking
+        self.locale = locale
 
     @property
     def cache_max_age(self):
@@ -1861,20 +1875,19 @@ class RatingRanking(BasicPrintout):
 
         rows.extend((rank,
                      Paragraph(r[0].description, normal_style),
-                     r[1], r[2], '  '+str(r[3]), r[4])
+                     r[1], r[2], format_decimal(r[3], '0.00000', self.locale), r[4])
                     for rank, r in enumerate(self.ranking, 1))
 
-        desc_width = self.doc.width/self.columns*0.9 - rank_width*2 - scores_width*6
+        desc_width = self.doc.width - rank_width - scores_width*8
         style = [('SIZE', (0,0), (-1,-1), caption_style.fontSize),
                  ('LEADING', (0,0), (-1,-1), caption_style.leading),
                  ('FONT', (0,0), (-1,0), caption_style.fontName),
-                 ('ALIGN', (0,1), (0,-1), 'RIGHT'),
-                 ('ALIGN', (2,1), (3,-1), 'RIGHT'),
-                 ('ALIGN', (4,1), (4,-1), 'LEFT'),
-                 ('ALIGN', (5,1), (-1,-1), 'RIGHT'),
+                 ('ALIGN', (2,0), (-1,0), 'RIGHT'),
+                 ('ALIGN', (0,0), (0,-1), 'RIGHT'),
+                 ('ALIGN', (2,1), (-1,-1), 'RIGHT'),
                  ('LINEBELOW', (0,1), (-1,-1), 0.25, colors.black)]
 
         yield Table(rows, (rank_width, desc_width,
                            scores_width*2, scores_width*2, scores_width*2,
-                           rank_width),
+                           scores_width*2),
                     style=style)
