@@ -23,7 +23,9 @@ Ext.define('SoL.module.Tourney', {
     id: 'tourney-win',
     iconCls: 'tourney-icon',
     launcherText: null,
-    launcherTooltip: _('<b>Tourney</b><br />Tourney management'),
+    launcherTooltip: function() {
+        return _('<b>Tourney</b><br />Tourney management');
+    },
 
     createOrShowWindow: function(tourney) {
         var me = this;
@@ -95,7 +97,7 @@ Ext.define('SoL.module.Tourney', {
                         + me.tourney.description
                         + '", ' +
                         MP.data.MetaData.renderDate(me.tourney.date)),
-                taskbuttonTooltip: me.launcherTooltip,
+                taskbuttonTooltip: me.getLauncherTooltip(),
                 iconCls: me.iconCls,
                 width: winWidth,
                 height: winHeight,
