@@ -23,6 +23,7 @@ Ext.define('SoL.module.Tourneys.Actions', {
         DOWNLOAD_TOURNEY_ACTION: 'download_tourney',
         REPLAY_TOURNEY_ACTION: 'duplicate_tourney',
         SHOW_TOURNEY_ACTION: 'show_tourney',
+        SHOW_CHAMPIONSHIP_ACTION: 'show_championship',
         MANAGE_COMPETITORS_ACTION: 'manage_competitors'
     },
 
@@ -74,6 +75,23 @@ Ext.define('SoL.module.Tourneys.Actions', {
             }
         }));
 
+        me.showChampionshipAction = me.addAction(new Ext.Action({
+            itemId: ids.SHOW_CHAMPIONSHIP_ACTION,
+            text: _('Championship'),
+            tooltip: _('Show the championship this tourney belongs.'),
+            iconCls: 'championships-icon',
+            disabled: true,
+            needsOneSelectedRow: true,
+            needsCleanStore: true,
+            handler: function() {
+                var record = me.component.getSelectionModel().getSelection()[0];
+                var idchampionship = record.get('idchampionship');
+                var module = me.module.app.getModule('championships-win');
+
+                module.createOrShowWindow(null, null, null, null, idchampionship);
+            }
+        }));
+
         me.manageTourneyCompetitorsAction = me.addAction(new Ext.Action({
             itemId: ids.MANAGE_COMPETITORS_ACTION,
             text: _('Competitors'),
@@ -191,6 +209,7 @@ Ext.define('SoL.module.Tourneys.Actions', {
                   me.showTourneyAction,
                   me.manageTourneyCompetitorsAction,
                   me.duplicateTourneyAction,
+                  me.showChampionshipAction,
                   me.downloadTourneyAction);
 
         tbar.add.apply(tbar, args);
@@ -377,8 +396,12 @@ Ext.define('SoL.module.Tourneys', {
 
     id: 'tourneys-win',
     iconCls: 'tourneys-icon',
-    launcherText: _('Tourneys'),
-    launcherTooltip: _('<b>Tourneys</b><br />Basic tourneys management'),
+    launcherText: function() {
+        return _('Tourneys');
+    },
+    launcherTooltip: function() {
+        return _('<b>Tourneys</b><br />Basic tourneys management');
+    },
 
     config: {
         xtype: 'editable-grid',
@@ -415,6 +438,7 @@ Ext.define('SoL.module.Tourneys', {
                     ]
                 });
                 callback(cfg);
+                me.app.on('logout', function() { delete cfg.metadata; }, me, { single: true });
             });
         } else {
             callback(cfg);
@@ -534,8 +558,8 @@ Ext.define('SoL.module.Tourneys', {
 
                 win = desktop.createWindow({
                     id: me.id,
-                    title: (me.windowTitle || me.launcherText) + filteredOn,
-                    taskbuttonTooltip: me.launcherTooltip,
+                    title: (me.windowTitle || me.getLauncherText()) + filteredOn,
+                    taskbuttonTooltip: me.getLauncherTooltip(),
                     iconCls: me.iconCls,
                     items: [config],
                     x: size.x,
@@ -614,7 +638,11 @@ Ext.define('SoL.module.MyTourneys', {
     init: function() {
         var me = this;
         var user = me.app.user;
-        me.config.dataURL += '?filter_idowner=' + (user.is_admin ? 'NULL' : user.user_id);
+        if(!me.config.orig_dataURL) me.config.orig_dataURL = me.config.dataURL;
+        me.config.dataURL = Ext.String.urlAppend(me.config.orig_dataURL,
+                                                 'filter_idowner=' + (user.is_admin
+                                                                      ? 'NULL'
+                                                                      : user.user_id));
         me.windowTitle = Ext.String.format(_('Tourneys managed by {0}'), user.fullname);
         me.callParent();
     }
